"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.JSONRPCClient = exports.JSONRPC20Exception = void 0;
const uuid = __importStar(require("uuid"));
class JSONRPC20Exception extends Error {
    constructor(error) {
        super(error.message);
        this.error = error;
    }
}
exports.JSONRPC20Exception = JSONRPC20Exception;
class JSONRPCClient {
    constructor({ url, timeout, token }) {
        this.url = url;
        this.timeout = timeout;
        this.token = token;
    }
    makePayload(method, params) {
        return {
            jsonrpc: '2.0',
            method,
            id: uuid.v4(),
            params,
        };
    }
    callMethod(method, params, { timeout } = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            const payload = this.makePayload(method, params);
            const headers = new Headers();
            headers.set('content-type', 'application/json');
            headers.set('accept', 'application/json');
            if (this.token) {
                headers.set('authorization', this.token);
            }
            const response = yield fetch(this.url, {
                method: 'POST',
                body: JSON.stringify(payload),
                headers,
            });
            const rpcResponse = yield (() => __awaiter(this, void 0, void 0, function* () {
                const responseText = yield response.text();
                try {
                    return JSON.parse(responseText);
                }
                catch (ex) {
                    console.error('error', ex);
                    throw new JSONRPC20Exception({
                        name: 'parse error',
                        code: 100,
                        message: 'The response from the service could not be parsed',
                        error: {
                            originalMessage: ex instanceof Error ? ex.message : 'Unknown error',
                            responseText,
                        },
                    });
                }
            }))();
            if ('error' in rpcResponse) {
                throw new JSONRPC20Exception({
                    name: rpcResponse.error.name,
                    code: rpcResponse.error.code,
                    message: rpcResponse.error.message,
                    error: rpcResponse.error.error,
                });
            }
            return rpcResponse.result;
        });
    }
}
exports.JSONRPCClient = JSONRPCClient;
//# sourceMappingURL=JSONRPC20.js.map