import { JSONObject } from '../../../json';
import { JSONLikeObject } from '../../../jsonLike';
import { ServiceClient, ServiceClientParams } from '../../JSONRPC11/ServiceClient';
import { ControlledField } from './ControlledField';
import { EpochTimeMS, Sample, SampleId, SampleNodeId, SampleVersion, SDKBoolean, Username, WSUPA } from './Sample';
export type ControlledFieldKey = string;
export interface FieldGroup extends JSONObject {
    name: string;
    title: string;
    fields: Array<ControlledFieldKey>;
}
export type FieldGroups = Array<FieldGroup>;
export interface StatusResult extends JSONObject {
    state: string;
    message: string;
    version: string;
    git_url: string;
    git_commit_hash: string;
}
export interface GetSampleParams {
    id: SampleId;
    version?: number;
    as_admin?: SDKBoolean;
}
export type GetSampleResult = Sample;
export interface GetDataLinksFromSampleParams {
    id: SampleId;
    version: SampleVersion;
    effective_time?: EpochTimeMS;
}
export type DataId = string;
export interface DataLink extends JSONObject {
    linkid: string;
    upa: WSUPA;
    dataid: DataId | null;
    id: SampleId;
    version: SampleVersion;
    node: SampleNodeId;
    created: EpochTimeMS;
    createdby: Username;
    expiredby: Username | null;
    expired: EpochTimeMS | null;
}
export type DataLinks = Array<DataLink>;
export interface GetDataLinksFromSampleResult {
    links: DataLinks;
}
export type KeyPrefix = 0 | 1 | 2;
export interface GetMetadataKeyStaticMetadataParams extends JSONObject {
    keys: Array<string>;
    prefix: KeyPrefix;
}
export interface StaticMetadataValue {
    display_name: string;
    description?: string;
}
export interface StaticMetadata {
    [key: string]: StaticMetadataValue;
}
export interface GetMetadataKeyStaticMetadataResult {
    static_metadata: StaticMetadata;
}
export interface GetSampleACLsParams extends JSONObject {
    id: SampleId;
    as_admin: SDKBoolean;
}
export interface SampleACLs extends JSONObject {
    owner: Username;
    admin: Array<Username>;
    write: Array<Username>;
    read: Array<Username>;
}
export type GetSampleACLsResult = SampleACLs;
export interface GetFieldDefinitionsParams extends JSONObject {
    keys: Array<string>;
}
export interface GetFieldDefinitionsResult extends JSONLikeObject {
    fields: Array<ControlledField>;
}
export interface GetFieldGroupsParams {
}
export interface GetFieldGroupsResult extends JSONObject {
    groups: FieldGroups;
}
export interface CreateDataLinksParam extends JSONLikeObject {
    upa: string;
    id: string;
    version: number;
    node: string;
    dataid?: string;
    update?: boolean;
    as_admin?: boolean;
    as_user?: Username;
}
export interface CreateDataLinksResult {
    new_link: DataLink;
}
export interface ExpireDataLinksParam extends JSONLikeObject {
    upa: string;
    dataid?: string;
    as_admin?: boolean;
    as_user?: Username;
}
export interface SampleServiceClientParams extends ServiceClientParams {
    url: string;
}
export default class SampleServiceClient extends ServiceClient {
    module: string;
    status(): Promise<StatusResult>;
    get_sample(params: GetSampleParams): Promise<GetSampleResult>;
    get_data_links_from_sample(params: GetDataLinksFromSampleParams): Promise<GetDataLinksFromSampleResult>;
    get_metadata_key_static_metadata(params: GetMetadataKeyStaticMetadataParams): Promise<GetMetadataKeyStaticMetadataResult>;
    get_sample_acls(params: GetSampleACLsParams): Promise<GetSampleACLsResult>;
    create_data_link(params: CreateDataLinksParam): Promise<CreateDataLinksResult>;
    expire_data_link(params: ExpireDataLinksParam): Promise<void>;
    get_field_definitions(params: GetFieldDefinitionsParams): Promise<GetFieldDefinitionsResult>;
    get_field_groups(): Promise<GetFieldGroupsResult>;
}
