interface ListenerParams {
    name: string;
    callback: (payload: Payload) => void;
    onError?: (error: Error) => void;
}
declare class Listener {
    name: string;
    callback: (payload: Payload) => void;
    onError?: (error: Error) => void;
    constructor({ name, callback, onError }: ListenerParams);
}
type Payload = any;
interface WaitingListenerParams extends ListenerParams {
    timeout?: number;
}
declare class WaitingListener extends Listener {
    started: Date;
    timeout: number;
    constructor(params: WaitingListenerParams);
}
type EnvelopeType = 'plain' | 'request' | 'reply';
interface EnvelopeBase {
    type: EnvelopeType;
    from: string;
    to: string;
    id: string;
    created: number;
}
interface PlainEnvelope extends EnvelopeBase {
    type: 'plain';
}
interface RequestEnvelope extends EnvelopeBase {
    type: 'request';
}
interface ReplyEnvelope extends EnvelopeBase {
    type: 'reply';
    inReplyTo: string;
    status: 'ok' | 'error';
}
type Envelope = PlainEnvelope | RequestEnvelope | ReplyEnvelope;
declare class Message {
    name: string;
    payload: any;
    id: string;
    created: Date;
    envelope: Envelope;
    constructor({ name, payload, envelope }: {
        name: string;
        payload: any;
        envelope: Envelope;
    });
    toJSON(): {
        envelope: Envelope;
        name: string;
        payload: any;
    };
}
export interface WindowChannelInitParams {
    window?: Window;
    host?: string;
    id?: string;
    to?: string;
}
export declare class WindowChannelInit {
    private readonly window;
    private readonly host;
    private readonly id;
    constructor(params?: WindowChannelInitParams);
    makeChannel(partnerId: string): WindowChannel;
    getId(): string;
}
export interface WindowChannelParams {
    window: Window;
    host: string;
    id: string;
    to: string;
}
interface Stats {
    sent: number;
    received: number;
    ignored: number;
}
export declare class WindowChannel {
    private readonly window;
    private readonly host;
    private readonly id;
    private partnerId;
    private awaitingResponses;
    private waitingListeners;
    private listeners;
    private lastId;
    private currentListener;
    private running;
    private readonly stats;
    constructor({ window, host, id, to }: WindowChannelParams);
    getId(): string;
    getPartnerId(): string;
    getStats(): Stats;
    receiveMessage(messageEvent: MessageEvent): void;
    listen(listener: Listener): void;
    on(messageId: string, callback: (payload: any) => any, onError?: (error: Error) => void): void;
    sendMessage(message: Message): void;
    send(name: string, payload: Payload): void;
    sendRequest(message: Message, handler: (status: 'ok' | 'error', response: any) => any): void;
    request(name: string, payload: Payload): Promise<unknown>;
    startMonitor(): void;
    listenOnce(listener: WaitingListener): void;
    once(name: string, timeout: number, callback: (payload: Payload) => void, onError?: (error: Error) => void): void;
    when(name: string, timeout: number): Promise<unknown>;
    setPartner(id: string): void;
    start(): WindowChannel;
    stop(): this;
}
export {};
